@@ -31,11 +31,10 @@ class Snowbank():
             sys.exit()
         self.filter = filter
 
-    def generate(self, actions):
+    def generate(self, action):
         db_conn = sqlite3.connect(self.db_file)
         cursor = db_conn.cursor()
-        action_str = ",".join(actions)
-        sql = queries.insert_graph(action_str)
+        sql = queries.insert_graph(action)
         cursor.execute(sql)
         db_conn.commit()
         cursor.execute(queries.get_last_row_id())
